@@ -3,13 +3,13 @@ from .main import AES
 # --------------------
 # Project information
 # --------------------
-__name__ = "AES_Python"
+__name__ = "AES-Python"
 __author__ = 'Gabriel Lindeblad'
 __copyright__ = 'Copyright 2024, Gabriel Lindeblad'
 __license__ = 'MIT'
 __email__ = 'gabriel.lindeblad@icloud.com'
 __status__ = 'Development'
-__date__ = '2024-04-21'
+__date__ = '2024-04-25'
 __description__ = 'AES (Advanced Encryption Standard) implementation in Python-3.12'
 __platforms__ = 'Windows, Linux, MacOS'
 __all__ = ['AES']
